# Installation

`pytcube` is a pure python package. It can easily be installed with pip or conda.

::::{tab-set}
:::{tab-item} pip
```bash
pip install pytcube
```
:::

:::{tab-item} conda
```bash
conda install pytcube
```
:::
::::
